Index: src/gpu/GrGpu.h |
diff --git a/src/gpu/GrGpu.h b/src/gpu/GrGpu.h |
index 1ae2f5856bd4cfe8a521f9744991f26170c5793a..48bb0d6400dd9a52c22ac14fc2302930a45b1027 100644 |
--- a/src/gpu/GrGpu.h |
+++ b/src/gpu/GrGpu.h |
@@ -62,8 +62,8 @@ public: |
// Called by GrContext when the underlying backend context has been destroyed. |
// GrGpu should use this to ensure that no backend API calls will be made from |
// here onward, including in its destructor. Subclasses should call |
- // INHERITED::contextAbandonded() if they override this. |
- virtual void contextAbandonded(); |
+ // INHERITED::contextAbandoned() if they override this. |
+ virtual void contextAbandoned(); |
/** |
* The GrGpu object normally assumes that no outsider is setting state |